@@ -149,7 +149,7 @@ atk_object_class_init (AtkObjectClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_ref (G_TYPE_OBJECT);
+  parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->set_property = atk_object_real_set_property;
   gobject_class->get_property = atk_object_real_get_property;
@@ -557,6 +557,7 @@ atk_object_get_role (AtkObject *accessible)
  * @accessible: an #AtkObject
  *
  * Gets the layer of the accessible.
+ * DEPRECATED: use atk_component_get_layer instead!
  *
  * Returns: an #AtkLayer which is the layer of the accessible
  **/
@@ -580,6 +581,7 @@ atk_object_get_layer (AtkObject *accessible)
  *
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
+ * DEPRECATED: use atk_component_get_mdi_zorder instead!
  *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
@@ -899,10 +901,12 @@ atk_object_real_get_property (GObject      *object,
       g_value_set_int (value, atk_object_get_role (accessible));
       break;
     case PROP_LAYER:
-      g_value_set_int (value, atk_object_get_role (accessible));
+      if (ATK_IS_COMPONENT (accessible))
+        g_value_set_int (value, atk_component_get_layer (ATK_COMPONENT (accessible)));
       break;
     case PROP_MDI_ZORDER:
-      g_value_set_int (value, atk_object_get_mdi_zorder (accessible));
+      if (ATK_IS_COMPONENT (accessible))
+        g_value_set_int (value, atk_component_get_mdi_zorder (ATK_COMPONENT (accessible)));
       break;
     case PROP_PARENT:
       g_value_set_object (value, atk_object_get_parent (accessible));
