@@ -242,6 +242,7 @@ struct _AtkPropertyValues
 
 typedef struct _AtkPropertyValues        AtkPropertyValues;
 
+typedef gboolean (*AtkFunction)          (gpointer data); 
 /*
  * For most properties the old_value field of AtkPropertyValues will
  * not contain a valid value.
@@ -363,19 +364,19 @@ void                      (* initialize)                         (AtkObject
    * The signal handler which is executed  when there is a focus event
    * for an object.
    */
-  void                    (*focus_event)          (AtkObject                  *accessible,
+  void                    (* focus_event)         (AtkObject                  *accessible,
                                                    gboolean                   focus_in);
   /*
    * The signal handler which is executed  when there is a property_change 
    * signal for an object.
    */
-  void                    (*property_change)      (AtkObject                  *accessible,
+  void                    (* property_change)     (AtkObject                  *accessible,
                                                    AtkPropertyValues          *values);
   /*
    * The signal handler which is executed  when there is a state_change 
    * signal for an object.
    */
-  void                    (*state_change)         (AtkObject                  *accessible,
+  void                    (* state_change)        (AtkObject                  *accessible,
                                                    const gchar                *name,
                                                    gboolean                   state_set);
   /*
@@ -384,6 +385,10 @@ void                      (* initialize)                         (AtkObject
    */
   void                    (*visible_data_changed) (AtkObject                  *accessible);
 
+  AtkFunction             pad1;
+  AtkFunction             pad2;
+  AtkFunction             pad3;
+  AtkFunction             pad4;
 };
 
 GType            atk_object_get_type   (void);
