@@ -174,11 +174,21 @@ void
 atk_focus_tracker_notify (AtkObject       *object)
 {
   FocusTracker *item;
+  static AtkObject *previous_focus_object = NULL;
   guint i;
 
   if (trackers == NULL)
     return;
 
+  if (object == previous_focus_object)
+    return;
+  else
+    {
+      if (previous_focus_object)
+        g_object_unref (previous_focus_object);
+      previous_focus_object = g_object_ref (object);
+    }
+  
   for (i = 0; i < trackers->len; i++)
   {
     item = &g_array_index (trackers, FocusTracker, i);
@@ -286,15 +296,19 @@ atk_remove_key_event_listener (guint listener_id)
 AtkObject*
 atk_get_root (void)
 {
-  AtkUtilClass *klass = g_type_class_peek (ATK_TYPE_UTIL);
+  AtkUtilClass *klass = g_type_class_ref (ATK_TYPE_UTIL);
+  AtkObject    *retval;
   if (klass->get_root)
     {
-      return klass->get_root ();
+      retval = klass->get_root ();
     }
   else
     {
-      return NULL;
+      retval = NULL;
     }
+  g_type_class_unref (klass);
+
+  return retval;
 }
 
 /**
